---
title: "ENS"
description: "Terraform compliance scanning for ENS — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Government" variant="tip" />

**Issuing body:** [CCN](https://www.ccn.cni.es)
**Jurisdiction:** Country — Europe
**Countries:** ES


## Assessment

Assess your infrastructure against ENS for free at any tier:

```bash
complyform assess --frameworks=ens
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=ens
```

## Related Frameworks

- [GDPR](/frameworks/gdpr)
- [NIS2 Directive](/frameworks/nis2)
- [DORA](/frameworks/dora)
- [BSI C5](/frameworks/bsi_c5)
